@@ -25,10 +25,11 @@ from sgp4.ext import invjday, newtonnu, rv2coe
 from sgp4.functions import days2mdhms, _day_of_year_to_month_day
 from sgp4.propagation import sgp4, sgp4init
 from sgp4 import conveniences, io, omm
-from sgp4.exporter import export_tle
+from sgp4.exporter import export_omm, export_tle
 import sgp4.model as model
 
 _testcase = TestCase('setUp')
+_testcase.maxDiff = 9999
 assertEqual = _testcase.assertEqual
 assertAlmostEqual = _testcase.assertAlmostEqual
 assertRaises = _testcase.assertRaises
@@ -290,6 +291,13 @@ def assert_wgs84(sat):
 #                            Special Cases
 #
 
+def test_satnum_leading_spaces():
+    # https://github.com/brandon-rhodes/python-sgp4/issues/81
+    l1 = '1  4859U 21001A   21007.63955392  .00000000  00000+0  00000+0 0  9990'
+    l2 = '2  4859 000.0000 000.0000 0000000 000.0000 000.0000 01.00000000    09'
+    sat = Satrec.twoline2rv(l1, l2)
+    assertEqual(sat.satnum, 4859)
+
 def test_satnum_alpha5_encoding():
     def make_sat(satnum_string):
         return Satrec.twoline2rv(LINE1.replace('00005', satnum_string),
@@ -528,6 +536,7 @@ def run_satellite_against_tcppver(twoline2rv, invoke, expected_errors):
     # output in tcppver.out.
 
     data = get_data(__name__, 'tcppver.out')
+    data = data.replace(b'\r', b'')
     tcppver_lines = data.decode('ascii').splitlines(True)
 
     error_list = []
@@ -733,6 +742,38 @@ def assert_satellites_match(sat1, sat2):
             value2 = round(value2, 10)
         assertEqual(value1, value2, '%s %r != %r' % (attr, value1, value2))
 
+# Live example of OMM:
+# https://celestrak.com/NORAD/elements/gp.php?INTDES=2020-025&FORMAT=JSON-PRETTY
+
+def test_omm_export():
+    line0, line1, line2 = VANGUARD_TLE.splitlines()
+    sat = Satrec.twoline2rv(line1, line2)
+
+    fields = export_omm(sat, 'VANGUARD 1')
+    assertEqual(fields, {
+        'ARG_OF_PERICENTER': 162.2516,
+        'BSTAR': -2.2483e-05,
+        'CENTER_NAME': 'EARTH',
+        'CLASSIFICATION_TYPE': 'U',
+        'ECCENTRICITY': 0.1845686,
+        'ELEMENT_SET_NO': 999,
+        'EPHEMERIS_TYPE': 0,
+        'EPOCH': '2020-10-13T04:52:48.472320',
+        'INCLINATION': 34.2443,
+        'MEAN_ANOMALY': 205.2356,
+        'MEAN_ELEMENT_THEORY': 'SGP4',
+        'MEAN_MOTION': 10.84869164,
+        'MEAN_MOTION_DDOT': 0.0,
+        'MEAN_MOTION_DOT': -1.6e-07,
+        'NORAD_CAT_ID': 5,
+        'OBJECT_ID': '1958-002B',
+        'OBJECT_NAME': 'VANGUARD 1',
+        'RA_OF_ASC_NODE': 225.5254,
+        'REF_FRAME': 'TEME',
+        'REV_AT_EPOCH': 21814,
+        'TIME_SYSTEM': 'UTC',
+    })
+
 # ----------------------------------------------------------------------
 
 def load_tests(loader, tests, ignore):
